# pylabtools

`pylabtools` is a Python utility library that provides various helper functions:

## Installation

You can install pylabtools using pip:
    
```bash
pip install pylabtools
```

## Testing

You can run the unit tests using the following commands:

```bash
python -m unittest discover tests

or 

pytest tests
```

## Contributing

If you find a bug or have an idea for a new feature, please open an issue on the GitHub repository. Pull requests are welcome!